Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5430)

Unified Diff: chrome/browser/device_orientation/accelerometer_mac.h

Issue 3275002: Added tested and corrected accelerometer support for the following MacBook / MacBook Pro models: (Closed)
Patch Set: Created 10 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/device_orientation/accelerometer_mac.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/device_orientation/accelerometer_mac.h
diff --git a/chrome/browser/device_orientation/accelerometer_mac.h b/chrome/browser/device_orientation/accelerometer_mac.h
index 873ff798ca5b075b005b751b20e663258010ecf8..5771cea3b391e04289b21750a8ff1f915bc844b6 100644
--- a/chrome/browser/device_orientation/accelerometer_mac.h
+++ b/chrome/browser/device_orientation/accelerometer_mac.h
@@ -78,10 +78,12 @@ class AccelerometerMac : public DataFetcher {
// Extend the sign of an integer of size bytes to a 32-bit one.
static int ExtendSign(int value, size_t size);
+ struct GenericMacbookSensor;
struct SensorDescriptor;
struct AxisData;
- // List of supported sensors.
+ // Generic sensor data and list of supported sensors.
+ static const GenericMacbookSensor kGenericSensor;
static const SensorDescriptor kSupportedSensors[];
// Local sensor if supported, else NULL.
« no previous file with comments | « no previous file | chrome/browser/device_orientation/accelerometer_mac.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698